@@ -18,7 +18,7 @@ class CLIColor:
         parser = argparse.ArgumentParser(description="CLI that utilize color_palette_at library.")
         parser.add_argument('file_name', type=str, help="Path to the file image.")
         parser.add_argument('limit', type=int, nargs='?', default=10, help="Number of colors that will be returned, default value: 10.")
-        parser.add_argument('output_format', type=str, nargs='?', default='hex', help="Format in which output colors will be returned, default value: hex")
+        parser.add_argument('output_format', type=str, nargs='?', default='hex', help="Format in which output colors will be returned, default value: hex.")
         
         arguments = parser.parse_args()
         arguments.output_format = arguments.output_format.lower()
